<?php

namespace wpbel\classes\repositories;

use wpbel\classes\helpers\Post_Helper;

class History
{
    const BULK_OPERATION = 'bulk';
    const INLINE_OPERATION = 'inline';

    private $wpdb;
    private $sub_system;
    private $history_table;
    private $history_items_table;

    public function __construct(string $post_type = "")
    {
        global $wpdb;
        $this->wpdb = $wpdb;
        $this->history_table = $this->wpdb->prefix . 'itbbc_history';
        $this->history_items_table = $this->wpdb->prefix . 'itbbc_history_items';
        $this->set_sub_system($post_type);
    }

    public static function get_operation_types()
    {
        return [
            self::BULK_OPERATION => __('Bulk Operation', 'ithemeland-wordpress-bulk-posts-editing-lite'),
            self::INLINE_OPERATION => __('Inline Operation', 'ithemeland-wordpress-bulk-posts-editing-lite'),
        ];
    }

    public static function get_operation_type($operation_type)
    {
        $operation_types = self::get_operation_types();
        return (isset($operation_types[$operation_type])) ? $operation_types[$operation_type] : "";
    }

    public function create_history($data)
    {
        $data['sub_system'] = $this->sub_system;
        $format = ['%d', '%s', '%s', '%s', '%s'];
        $this->wpdb->insert($this->history_table, $data, $format);
        return $this->wpdb->insert_id;
    }

    public function create_history_item($data)
    {
        $format = ['%d', '%d', '%s', '%s', '%s'];
        $this->wpdb->insert($this->history_items_table, $data, $format);
        return $this->wpdb->insert_id;
    }

    public function save_history_item($data)
    {
        if (empty($data['history_id']) || !isset($data['historiable_id']) || empty($data['name']) || empty($data['type'])) {
            return false;
        }

        return $this->create_history_item([
            'history_id' => intval($data['history_id']),
            'historiable_id' => intval($data['historiable_id']),
            'field' => serialize([
                'name' => sanitize_text_field($data['name']),
                'sub_name' => (!empty($data['sub_name'])) ? sanitize_text_field($data['sub_name']) : '',
                'type' => sanitize_text_field($data['type']),
                'action' => (!empty($data['action'])) ? sanitize_text_field($data['action']) : '',
                'undo_operator' => (!empty($data['undo_operator'])) ? sanitize_text_field($data['undo_operator']) : '',
                'redo_operator' => (!empty($data['redo_operator'])) ? sanitize_text_field($data['redo_operator']) : '',
                'extra_fields' => (!empty($data['extra_fields'])) ? esc_sql($data['extra_fields']) : [],
                'deleted_ids' => (!empty($data['deleted_ids'])) ? esc_sql($data['deleted_ids']) : [],
                'created_ids' => (!empty($data['created_ids'])) ? esc_sql($data['created_ids']) : [],
            ]),
            'prev_value' => (!empty($data['prev_value'])) ? serialize($data['prev_value']) : '',
            'new_value' => (!empty($data['new_value'])) ? serialize($data['new_value']) : '',
        ]);
    }

    public function get_histories($where = [], $limit = 10, $offset = 0)
    {
        $where_items = "history.reverted = 0 AND history.sub_system = '{$this->sub_system}' ";
        if (!empty($where)) {
            foreach ($where as $field => $value) {
                $field = esc_sql($field);
                $value = esc_sql($value);
                switch ($field) {
                    case 'operation_type':
                        $where_items .= " AND history.{$field} = '{$value}'";
                        break;
                    case 'user_id':
                        $where_items .= " AND history.{$field} = {$value}";
                        break;
                    case 'fields':
                        $fields = explode(',', $value);
                        if (!empty($fields) && is_array($fields)) {
                            foreach ($fields as $field_item) {
                                $where_items .= " AND history.{$field} LIKE '%{$field_item}%'";
                            }
                        }
                        break;
                    case 'operation_date':
                        $from = (!empty($value['from'])) ? date('Y-m-d H:i:s', strtotime($value['from'])) : null;
                        $to = (!empty($value['to'])) ? date('Y-m-d H:i:s', (strtotime($value['to']) + 86400)) : null;
                        if (!empty($from) || !empty($to)) {
                            if (!empty($from) & !empty($to)) {
                                $where_items .= " AND (history.{$field} BETWEEN '{$from}' AND '{$to}')";
                            } else if (!empty($from)) {
                                $where_items .= " AND history.{$field} >= '{$from}'";
                            } else {
                                $where_items .= " AND history.{$field} < '{$to}'";
                            }
                        }
                        break;
                }
            }
        }

        if (!current_user_can('administrator')) {
            $user_id = get_current_user_id();
            $where_items .= " AND history.user_id = {$user_id}";
        }

        $limit = intval(sanitize_text_field($limit));
        $offset = intval(sanitize_text_field($offset));

        $limit_offset = (!empty($offset)) ? "LIMIT {$limit}, {$offset}" : "LIMIT {$limit}";
        return $this->wpdb->get_results("SELECT * FROM {$this->history_table} history WHERE {$where_items} ORDER BY history.id DESC {$limit_offset}");
    }

    public function get_history_count($where = [])
    {
        $where_items = "history.reverted = 0 AND history.sub_system = '{$this->sub_system}' ";
        if (!empty($where)) {
            foreach ($where as $field => $value) {
                $field = esc_sql($field);
                $value = esc_sql($value);
                switch ($field) {
                    case 'operation_type':
                        $where_items .= " AND history.{$field} = '{$value}'";
                        break;
                    case 'user_id':
                        $where_items .= " AND history.{$field} = {$value}";
                        break;
                    case 'fields':
                        $fields = explode(',', $value);
                        if (!empty($fields) && is_array($fields)) {
                            foreach ($fields as $field_item) {
                                $where_items .= " AND history.{$field} LIKE '%{$field_item}%'";
                            }
                        }
                        break;
                    case 'operation_date':
                        $from = (!empty($value['from'])) ? date('Y-m-d H:i:s', strtotime($value['from'])) : null;
                        $to = (!empty($value['to'])) ? date('Y-m-d H:i:s', (strtotime($value['to']) + 86400)) : null;
                        if (!empty($from) || !empty($to)) {
                            if (!empty($from) & !empty($to)) {
                                $where_items .= " AND (history.{$field} BETWEEN '{$from}' AND '{$to}')";
                            } else if (!empty($from)) {
                                $where_items .= " AND history.{$field} >= '{$from}'";
                            } else {
                                $where_items .= " AND history.{$field} < '{$to}'";
                            }
                        }
                        break;
                }
            }
        }

        if (!current_user_can('administrator')) {
            $user_id = get_current_user_id();
            $where_items .= " AND history.user_id = {$user_id}";
        }

        $result = $this->wpdb->get_results("SELECT COUNT(id) as 'count' FROM {$this->history_table} history WHERE {$where_items} ORDER BY history.id DESC");
        return (!empty($result[0]) && !empty($result[0]->count)) ? $result[0]->count : 0;
    }

    public function get_history_items($history_id)
    {
        return $this->wpdb->get_results($this->wpdb->prepare("SELECT history_items.*, posts.post_title FROM {$this->history_items_table} history_items INNER JOIN {$this->wpdb->prefix}posts posts ON (history_items.historiable_id = posts.ID) WHERE history_id = %d", intval($history_id)));
    }

    public function get_history_rows($history_id)
    {
        return $this->wpdb->get_results($this->wpdb->prepare("SELECT * FROM {$this->history_items_table} WHERE history_id = %d", intval($history_id)));
    }

    public function get_latest_history()
    {
        return $this->wpdb->get_results("SELECT * FROM {$this->history_table} WHERE reverted = 0 AND sub_system = '{$this->sub_system}' ORDER BY id DESC LIMIT 1");
    }

    public function get_latest_reverted()
    {
        return $this->wpdb->get_results("SELECT * FROM {$this->history_table} WHERE reverted = 1 AND sub_system = '{$this->sub_system}' ORDER BY id DESC LIMIT 1");
    }

    public function delete_history($history_id)
    {
        $result = $this->wpdb->delete($this->history_table, [
            'id' => intval($history_id),
        ], [
            '%d',
        ]);

        return !empty($result);
    }

    public function get_history($history_id)
    {
        return $this->wpdb->get_results($this->wpdb->prepare("SELECT * FROM {$this->history_table} WHERE id = %d", intval($history_id)));
    }

    public function update_history($history_id, $where)
    {
        $result = $this->wpdb->update($this->history_table, $where, [
            'id' => intval($history_id),
        ]);

        return !empty($result);
    }

    public function clear_all()
    {
        $this->wpdb->query("DELETE FROM {$this->history_table} WHERE sub_system = '{$this->sub_system}'");
    }

    private function set_sub_system(string $post_type)
    {
        $post_type = Post_Helper::get_post_type_name($post_type);
        $this->sub_system = "wordpress_{$post_type}";
    }

    public function revert($history_id)
    {
        $post_repository = new Post();
        $history_items = $this->get_history_items(intval(esc_sql($history_id)));
        if (!empty($history_items)) {
            foreach ($history_items as $item) {
                $field = unserialize($item->field);
                if (is_array($field)) {
                    foreach ($field as $field_type => $field_name) {
                        if (is_numeric($field_type)) {
                            switch ($field_name) {
                                case '_thumbnail_id':
                                    $post_repository->update([$item->historiable_id], [
                                        'field_type' => 'main_field',
                                        'field' => $field_name,
                                        'value' => (unserialize($item->prev_value))['id']
                                    ]);
                                    break;
                                case 'post_delete':
                                    wp_untrash_post(intval($item->historiable_id));
                                    break;
                                default:
                                    $post_repository->update([$item->historiable_id], [
                                        'field_type' => 'main_field',
                                        'field' => $field_name,
                                        'value' => unserialize($item->prev_value)
                                    ]);
                            }
                        } else {
                            switch ($field_type) {
                                case 'custom_field':
                                    if (is_array($field_name)) {
                                        $prev = unserialize($item->prev_value);
                                        foreach ($field_name as $field_item) {
                                            $post_repository->update([$item->historiable_id], [
                                                'field_type' => 'custom_field',
                                                'field' => $field_item,
                                                'value' => (isset($prev[$field_type][$field_item])) ? $prev[$field_type][$field_item] : '',
                                                'operator' => 'taxonomy_replace'
                                            ]);
                                        }
                                    } else {
                                        $post_repository->update([$item->historiable_id], [
                                            'field_type' => 'custom_field',
                                            'field' => $field_name,
                                            'value' => unserialize($item->prev_value),
                                            'operator' => 'taxonomy_replace'
                                        ]);
                                    }
                                    break;
                                case 'taxonomy':
                                    if (is_array($field_name)) {
                                        $prev = unserialize($item->prev_value);
                                        foreach ($field_name as $field_item) {
                                            $post_repository->update([$item->historiable_id], [
                                                'field_type' => 'taxonomy',
                                                'field' => $field_item,
                                                'value' => (isset($prev[$field_type][$field_item])) ? $prev[$field_type][$field_item] : [],
                                                'operator' => 'taxonomy_replace'
                                            ]);
                                        }
                                    } else {
                                        $post_repository->update([$item->historiable_id], [
                                            'field_type' => 'taxonomy',
                                            'field' => $field_name,
                                            'value' => unserialize($item->prev_value),
                                            'operator' => 'taxonomy_replace'
                                        ]);
                                    }
                                    break;
                                default:
                                    break;
                            }
                        }
                    }
                }
            }
            $this->update_history($history_id, ['reverted' => 1]);
        }
    }

    public function reset($history_id)
    {
        $post_repository = new Post();
        $history_items = $this->get_history_items(intval($history_id));
        if (!empty($history_items)) {
            foreach ($history_items as $item) {
                $field = unserialize($item->field);
                if (is_array($field)) {
                    foreach ($field as $field_type => $field_name) {
                        if (is_numeric($field_type)) {
                            switch ($field_name) {
                                case '_thumbnail_id':
                                    $post_repository->update([$item->historiable_id], [
                                        'field_type' => 'main_field',
                                        'field' => $field_name,
                                        'value' => intval((unserialize($item->new_value))['id'])
                                    ]);
                                    break;
                                case 'post_delete':
                                    wp_trash_post(intval($item->historiable_id));
                                    break;
                                default:
                                    $post_repository->update([$item->historiable_id], [
                                        'field_type' => 'main_field',
                                        'field' => $field_name,
                                        'value' => unserialize($item->new_value)
                                    ]);
                            }
                        } else {
                            switch ($field_type) {
                                case 'custom_field':
                                    if (is_array($field_name)) {
                                        $new_val = unserialize($item->new_value);
                                        foreach ($field_name as $field_item) {
                                            $post_repository->update([$item->historiable_id], [
                                                'field_type' => 'custom_field',
                                                'field' => $field_item,
                                                'value' => (isset($new_val[$field_type][$field_item])) ? $new_val[$field_type][$field_item] : '',
                                                'operator' => 'taxonomy_replace'
                                            ]);
                                        }
                                    } else {
                                        $post_repository->update([$item->historiable_id], [
                                            'field_type' => 'custom_field',
                                            'field' => $field_name,
                                            'value' => unserialize($item->new_value),
                                            'operator' => 'taxonomy_replace'
                                        ]);
                                    }

                                    break;
                                case 'taxonomy':
                                    if (is_array($field_name)) {
                                        $new_val = unserialize($item->new_value);
                                        foreach ($field_name as $field_item) {
                                            $post_repository->update([$item->historiable_id], [
                                                'field_type' => 'taxonomy',
                                                'field' => $field_item,
                                                'value' => (isset($new_val[$field_type][$field_item])) ? $new_val[$field_type][$field_item] : [],
                                                'operator' => 'taxonomy_replace'
                                            ]);
                                        }
                                    } else {
                                        $post_repository->update([$item->historiable_id], [
                                            'field_type' => 'taxonomy',
                                            'field' => $field_name,
                                            'value' => unserialize($item->new_value),
                                            'operator' => 'taxonomy_replace'
                                        ]);
                                    }
                                    break;
                                default:
                                    break;
                            }
                        }
                    }
                }
            }
            $this->update_history($history_id, ['reverted' => 0]);
        }
    }
}
